@@ -16,7 +16,6 @@ class NotebooksClient(TagsSupportMixin, BaseClient):
             registry_username=None,
             registry_password=None,
             command=None,
-            container_user=None,
             shutdown_timeout=None,
             is_preemptible=None,
             is_public=None,
@@ -38,7 +37,6 @@ class NotebooksClient(TagsSupportMixin, BaseClient):
         :param str registry_username:
         :param str registry_password:
         :param str command:
-        :param str container_user:
         :param int shutdown_timeout:
         :param bool is_preemptible:
         :param bool is_public:
@@ -62,7 +60,6 @@ class NotebooksClient(TagsSupportMixin, BaseClient):
             registry_username=registry_username,
             registry_password=registry_password,
             command=command,
-            container_user=container_user,
             shutdown_timeout=shutdown_timeout,
             is_preemptible=is_preemptible,
             machine_type=machine_type,
