@@ -5,9 +5,6 @@ from click._compat import get_text_stderr
 import gradient.cli.auth
 import gradient.cli.clusters
 import gradient.cli.datasets
-import gradient.cli.experiments
-import gradient.cli.hyperparameters
-import gradient.cli.jobs
 import gradient.cli.machine_types
 import gradient.cli.machines
 import gradient.cli.models
@@ -15,13 +12,10 @@ import gradient.cli.notebooks
 import gradient.cli.projects
 import gradient.cli.secrets
 import gradient.cli.storage_providers
-import gradient.cli.tensorboards
 import gradient.cli.workflows
 from gradient.api_sdk.config import config
-if config.USE_LEGACY_DEPLOYMENTS:
-    import gradient.cli.deployments
-else:
-    import gradient.cli.gradient_deployments
+import gradient.cli.gradient_deployments
+
 
 def show(self, file=None):
     if file is None:
@@ -34,8 +28,10 @@ def show(self, file=None):
                 % (self.ctx.command_path, self.ctx.help_option_names[0]))
     if self.ctx is not None:
         color = self.ctx.color
-        click.echo(self.ctx.get_usage() + '\n%s' % hint, file=file, color=color)
-    msg = colorama.Fore.RED + 'Error: %s' % self.format_message() + colorama.Style.RESET_ALL
+        click.echo(self.ctx.get_usage() + '\n%s' %
+                   hint, file=file, color=color)
+    msg = colorama.Fore.RED + 'Error: %s' % self.format_message() + \
+        colorama.Style.RESET_ALL
     click.echo(msg, file=file, color=color)
 
 
